//! A module that handles `bar` partial for the `search_bar` partial and the home/index/main page in the `crabbysearch` frontend.

use maud::{html, Markup};

/// A functions that handles the html code for the bar for the `search_bar` partial and the
/// home/index/main page in the search engine frontend.
///
/// # Arguments
///
/// * `query` - It takes the current search query provided by user as an argument.
///
/// # Returns
///
/// It returns the compiled html code for the search bar as a result.
pub fn bar(query: &str, engines: Vec<(&'static str, bool)>) -> Markup {
    html!(
        .search_container {
            form action="/search" method="get" {
                div class="search_bar" {
                    input type="search" name="query" value=(query) placeholder="Type to search";
                    input type="hidden" name="page" value="1";
                    button type="submit"  {
                        img src="./images/magnifying_glass.svg" alt="Info icon for error box";
                    }
                }
                div class="search_bar" {
                    .engine_selection {
                        @for (name, selected) in engines{
                            @if selected {
                                .toggle_btn{
                                    span {(name)}
                                    label class="switch"{
                                        input type="checkbox" class="engine" checked;
                                        span class="slider round"{}
                                    }
                                }
                            }
                            @else {
                                .toggle_btn {
                                    (name)
                                    label class="switch"{
                                        input type="checkbox" class="engine";
                                        span class="slider round"{}
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    )
}
